summaryrefslogtreecommitdiff
path: root/src/main/scala/chisel3/util/CircuitMath.scala
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/scala/chisel3/util/CircuitMath.scala')
-rw-r--r--src/main/scala/chisel3/util/CircuitMath.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/main/scala/chisel3/util/CircuitMath.scala b/src/main/scala/chisel3/util/CircuitMath.scala
index 1174c71c..5e93b009 100644
--- a/src/main/scala/chisel3/util/CircuitMath.scala
+++ b/src/main/scala/chisel3/util/CircuitMath.scala
@@ -11,12 +11,12 @@ import chisel3._
* An alternative interpretation is it computes the minimum number of bits needed to represent x
* @example
* {{{ data_out := Log2(data_in) }}}
* @note Truncation is used so Log2(UInt(12412)) = 13*/
object Log2 {
/** Compute the Log2 on the least significant n bits of x */
def apply(x: Bits, width: Int): UInt = {
if (width < 2) {
- UInt(0)
+ UInt.Lit(0)
} else if (width == 2) {
x(1)
} else {
@@ -11,12 +11,12 @@ import chisel3._
* @example
* {{{ data_out := Log2(data_in) }}}
- * @note Truncation is used so Log2(UInt(12412)) = 13*/
+ * @note Truncation is used so Log2(UInt.Lit(12412)) = 13*/
object Log2 {
/** Compute the Log2 on the least significant n bits of x */